@@ -3,12 +3,7 @@ from typing import Any, Callable, List
 
 from iterwrapper import IterWrapper
 from functools import lru_cache
-
-async def async_enumerate(iterable, start: int = 0):
-    count = start
-    async for i in iterable:
-        yield (count, i)
-        count += 1
+from .entities.dispatcher import BaseDispatcher
 
 async def run_always_await(any_callable):
     if inspect.iscoroutine(any_callable):
@@ -20,14 +15,6 @@ def printer(value):
     print(value)
     return value
 
-def iw_group(iw: IterWrapper, key: Callable[[Any], Any]):
-    temp = {}
-    for i in iw:
-        k = key(i)
-        temp.setdefault(k, [])
-        temp[k].append(i)
-    return IterWrapper(temp.values()).map(list)
-
 def group_dict(iw: IterWrapper, key: Callable[[Any], Any]):
     temp = {}
     for i in iw:
@@ -49,6 +36,22 @@ def argument_signature(callable_target):
 def is_asyncgener(o):
     return inspect.isasyncgenfunction(o)
 
+@lru_cache(None)
+def isgeneratorfunction(o):
+    return inspect.isgeneratorfunction(o)
+
+@lru_cache(None)
+def iscoroutinefunction(o):
+    return inspect.iscoroutinefunction(o)
+
+@lru_cache(None)
+def isasyncgen(o):
+    return inspect.isasyncgen(o)
+
+@lru_cache(None)
+def isgenerator(o):
+    return inspect.isgenerator(o)
+
 async def whatever_gen_once(any_gen, *args, **kwargs):
     if inspect.isasyncgenfunction(any_gen):
         # 如果是异步生成器函数
@@ -69,4 +72,16 @@ async def whatever_gen_once(any_gen, *args, **kwargs):
 def flat_yield_from(l):
     for i in l:
         if type(i) == list:
-            yield from i
\ No newline at end of file
+            yield from i
+
+def dispatcher_mixin_handler(dispatcher: BaseDispatcher) -> List[BaseDispatcher]:
+    unbound_mixin = getattr(dispatcher, "mixin", [])
+    result = [dispatcher]
+
+    BaseDispatcher.__bases__
+    for i in unbound_mixin:
+        if issubclass(i, BaseDispatcher):
+            result.extend(dispatcher_mixin_handler(i))
+        else:
+            result.append(i)
+    return result
\ No newline at end of file
